DROP TABLE PRODUCT_DESC CASCADE CONSTRAINT;
DROP TABLE QUANTITY_DESC CASCADE CONSTRAINT;
DROP TABLE CREDIT_HOLDERS CASCADE CONSTRAINT;
DROP TABLE CREDIT_INFO CASCADE CONSTRAINT;
DROP TABLE PURCHASE_HIST CASCADE CONSTRAINT;
DROP TABLE BRANCH CASCADE CONSTRAINT;



CREATE TABLE PRODUCT_DESC
(
	P_NO NUMBER(7),
	P_DESC VARCHAR2(30),
	SELL_P NUMBER(7),
	COST_P NUMBER(7)
);

ALTER TABLE PRODUCT_DESC
ADD CONSTRAINT PRODUCT_DESC_P_NO_PK PRIMARY KEY(P_NO);


CREATE TABLE BRANCH
(
	BR_NAME VARCHAR2(30)
);

ALTER TABLE BRANCH
ADD CONSTRAINT BRANCH_BR_NAME_PK PRIMARY KEY(BR_NAME);


CREATE TABLE QUANTITY_DESC
(
	P_NO NUMBER(7),
	BR_NAME VARCHAR2(30),
	QIH NUMBER(7),
	CONSTRAINT QUANTITY_DESC_BR_NAME_FK FOREIGN KEY(BR_NAME)
	REFERENCES BRANCH(BR_NAME) ON DELETE CASCADE
);

CREATE TABLE CREDIT_HOLDERS
(
	SUSPENDED CHAR(10),
	CLIENT_NO NUMBER(7),
	CLIENT_NAME VARCHAR2(30),
	CLIENT_CITY VARCHAR2(30),
	CLIENT_ADDRESS VARCHAR2(40),
	MEM_SINCE DATE,
	CREDIT_REM NUMBER(7)
);

ALTER TABLE CREDIT_HOLDERS
ADD CONSTRAINT CREDIT_HOLDERS_CLIENT_NO_PK PRIMARY KEY(CLIENT_NO);

CREATE TABLE CREDIT_INFO
(
	CLIENT_NO NUMBER(7),
	DUE_DATE DATE,
	PAY_DATE DATE,
	CONSTRAINT CREDIT_INFO_CLIENT_NO_FK FOREIGN KEY(CLIENT_NO)
	REFERENCES CREDIT_HOLDERS(CLIENT_NO) ON DELETE CASCADE
);



CREATE TABLE PURCHASE_HIST
(
	P_NO NUMBER(7),
	BR_NAME VARCHAR2(30),
	PRH_DATE DATE,
	QTY_PCH NUMBER(7),
	CONSTRAINT PURCHASE_HIST_P_NO_FK FOREIGN KEY(P_NO) 
	REFERENCES PRODUCT_DESC(P_NO), 
	CONSTRAINT PURCHASE_HIST_BR_NAME_FK FOREIGN KEY(BR_NAME) 
	REFERENCES BRANCH(BR_NAME) ON DELETE CASCADE
);


GRANT SELECT, UPDATE
ON QUANTITY_DESC
TO STORE;

GRANT SELECT, INSERT
ON CREDIT_INFO
TO STORE;

GRANT SELECT
ON PRODUCT_DESC
TO STORE;

GRANT SELECT, UPDATE
ON CREDIT_HOLDERS
TO STORE;

GRANT REFERENCES
ON PRODUCT_DESC
TO STORE;

GRANT REFERENCES
ON CREDIT_HOLDERS
TO STORE;


ALTER TABLE CREDIT_INFO
ADD CONSTRAINT CREDIT_HOLDERS_PK PRIMARY KEY(CLIENT_NO,DUE_DATE);


ALTER TABLE QUANTITY_DESC
ADD CONSTRAINT QTY_DESC_P_NO_BR_NAME_PK PRIMARY KEY(P_NO,BR_NAME);


ALTER TABLE PURCHASE_HIST
ADD CONSTRAINT PURCHASE_HIST_PK PRIMARY KEY(P_NO, BR_NAME, PRH_DATE);





CREATE SEQUENCE S_ORD
   MINVALUE 1 
   MAXVALUE 9999999 
   INCREMENT BY 1 
   START WITH 1
   NOCACHE 
   NOORDER 
   NOCYCLE;

insert into PRODUCT_DESC
values(1,'PENTIUM',55,45);

insert into PRODUCT_DESC
values(2,'PENTIUM-III',350,300);

insert into PRODUCT_DESC
values(3,'PRINTER',30,20);

insert into PRODUCT_DESC
values(4,'RIVA TNT',100,90);

insert into PRODUCT_DESC
values(5,'MONITOR',75,60);



insert into BRANCH
values('NEW YORK');

insert into BRANCH
values('WASHINGTON');

insert into BRANCH
values('SAN FRANSISCO');



insert into QUANTITY_DESC
values(1,'NEW YORK',50);
				
insert into QUANTITY_DESC
values(1,'WASHINGTON',0);
					
insert into QUANTITY_DESC
values(1,'SAN FRANSISCO',150);
					
insert into QUANTITY_DESC
values(2,'NEW YORK',20);
				
insert into QUANTITY_DESC
values(2,'WASHINGTON',75);
								
insert into QUANTITY_DESC
values(2,'SAN FRANSISCO',55);
					
insert into QUANTITY_DESC
values(3,'NEW YORK',10);
				
insert into QUANTITY_DESC
values(3,'WASHINGTON',0);
					
insert into QUANTITY_DESC
values(3,'SAN FRANSISCO',25);
					
insert into QUANTITY_DESC
values(4,'NEW YORK',15);
				
insert into QUANTITY_DESC
values(4,'WASHINGTON',0);
					
insert into QUANTITY_DESC
values(4,'SAN FRANSISCO',10);
					
insert into QUANTITY_DESC
values(5,'NEW YORK',65);
				
insert into QUANTITY_DESC
values(5,'WASHINGTON',0);
					
insert into QUANTITY_DESC
values(5,'SAN FRANSISCO',90);








insert into CREDIT_HOLDERS
values('NO',1 ,'FARAAN','WASHINGTON','LAARI ADDA','01-MAY-92',1000);

insert into CREDIT_HOLDERS
values('YES',2 ,'BUDDY','NEW YORK','PIPRI','01-AUG-92',0);

insert into CREDIT_HOLDERS
values('NO',3 ,'MUSTAFA','SAN FRANSISCO','NORTH NAZIMABAD','01-JAN-97',2000);

insert into CREDIT_HOLDERS
values('NO',4 ,'SAQIB','WASHINGTON','GULSHAN','01-MAY-98',1000);

insert into CREDIT_HOLDERS
values('NO',5 ,'ALI','SAN FRANSISCO','GULSHAN','01-MAY-96',1000);


